pub fn build_chunk_pipeline(
graph: &mut Graph<Box<dyn ChunkNode>>,
) -> ChunkRegistryExpand description
Build the chunk graph from the registry. Allocates resources, adds every node in registry order, and returns the ids the job addresses.
pub fn build_chunk_pipeline(
graph: &mut Graph<Box<dyn ChunkNode>>,
) -> ChunkRegistryBuild the chunk graph from the registry. Allocates resources, adds every node in registry order, and returns the ids the job addresses.