#[repr(C)]pub struct TerrainGpu {Show 14 fields
pub frequency: f32,
pub height_octaves: f32,
pub height_amp: f32,
pub height_gain: f32,
pub height_lacunarity: f32,
pub ridge_tiles: f32,
pub ridge_octaves: f32,
pub ridge_gain: f32,
pub ridge_lacunarity: f32,
pub ridge_strength: f32,
pub water_height: f32,
pub height_scale: f32,
pub fd_eps: f32,
pub enabled: f32,
}Expand description
Terrain noise parameters as the shaders read them (14 floats = 56 bytes,
matching struct TerrainGpu in the realize/bake shaders — the CONTAINING
params structs pad back up to a 16-byte multiple). Octave counts ride as
floats and are cast in-shader.
Fields
frequency: f32height_octaves: f32height_amp: f32height_gain: f32height_lacunarity: f32ridge_tiles: f32ridge_octaves: f32ridge_gain: f32ridge_lacunarity: f32ridge_strength: f32water_height: f32height_scale: f32fd_eps: f32enabled: f32Trait Implementations
Sourceimpl Clone for TerrainGpu
impl Clone for TerrainGpu
Sourcefn clone(&self) -> TerrainGpu
fn clone(&self) -> TerrainGpu
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TerrainGpu
impl Debug for TerrainGpu
Sourceimpl PartialEq for TerrainGpu
impl PartialEq for TerrainGpu
Sourcefn eq(&self, other: &TerrainGpu) -> bool
fn eq(&self, other: &TerrainGpu) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for TerrainGpu
impl Pod for TerrainGpu
impl StructuralPartialEq for TerrainGpu